@@ -28,6 +28,11 @@ echo "API_RATE_LIMIT=False" >> $localconf
 echo "VOLUME_BACKING_FILE_SIZE=22G" >> $localconf
 echo "CINDER_LVM_TYPE=thin" >> $localconf
 
+# Set DevStack's PYTHON3_VERSION variable if CI scripts specify it
+if ! [[ -z "PYTHON3_VERSION" ]]; then
+echo "PYTHON3_VERSION=$PYTHON3_VERSION" >> $localconf
+fi
+
 # NOTE(mkoderer): switch to keystone v3 by default
 echo "IDENTITY_API_VERSION=3" >> $localconf
 
@@ -88,6 +93,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     # Run dummy driver CI job using standalone approach for running
     # manila API service just because we need to test this approach too,
     # that is very useful for development needs.
+    echo "MANILA_USE_UWSGI=False" >> $localconf
     echo "MANILA_USE_MOD_WSGI=False" >> $localconf
 
     echo "SHARE_DRIVER=$driver_path" >> $localconf
@@ -135,6 +141,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     echo "MANILA_OPTGROUP_adminnet_network_plugin_ipv4_enabled=True" >> $localconf
 
     export MANILA_TEMPEST_CONCURRENCY=24
+    export MANILA_CONFIGURE_DEFAULT_TYPES=False
 
 elif [[ "$DRIVER" == "lvm" ]]; then
     MANILA_SERVICE_IMAGE_ENABLED=True
@@ -167,6 +174,7 @@ if [[ "$MANILA_SERVICE_IMAGE_ENABLED" == True ]]; then
     echo "MANILA_SERVICE_IMAGE_NAME=$MANILA_SERVICE_IMAGE_NAME" >> $localconf
 fi
 echo "MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS=$DEFAULT_EXTRA_SPECS" >> $localconf
+echo "MANILA_CONFIGURE_DEFAULT_TYPES=${MANILA_CONFIGURE_DEFAULT_TYPES:-True}" >> $localconf
 
 # Enabling isolated metadata in Neutron is required because
 # Tempest creates isolated networks and created vm's in scenario tests don't
